@@ -1,5 +1,8 @@
+import traceback
+
+from flask import current_app as cap
 from werkzeug.routing import RequestRedirect
-from werkzeug.exceptions import MethodNotAllowed
+from werkzeug.exceptions import MethodNotAllowed, HTTPException
 
 
 class BaseNormalize(object):
@@ -56,11 +59,32 @@ class DefaultNormalizeMixin(
 ):
     def normalize(self, ex, exc_class=None, **kwargs):
         """
-        Collects the default normalize Mixins used in ErrorHandler
 
-        :param ex:
-        :param exc_class:
-        :param kwargs:
-        :return:
+        :param ex: Exception
+        :param exc_class: overrides ApiProblem class
+        :return: new Exception instance of HTTPException
         """
-        return super().normalize(ex, exc_class)
+        # noinspection PyPep8Naming
+        ExceptionClass = exc_class
+        ex = super().normalize(ex, exc_class)
+
+        if isinstance(ex, ExceptionClass):
+            return ex
+
+        tb = traceback.format_exc()
+        if cap.config['DEBUG']:
+            mess = tb
+        else:
+            mess = cap.config['ERROR_DEFAULT_MSG']
+
+        _ex = ExceptionClass(mess, **kwargs)
+
+        if isinstance(ex, HTTPException):
+            _ex.code = ex.code
+            _ex.description = ex.description
+            _ex.response = ex.response if hasattr(ex, 'response') else None
+            _ex.headers.update(**(ex.headers if hasattr(ex, 'headers') else {}))
+        else:
+            cap.logger.error(tb)
+
+        return _ex
